@@ -1,8 +1,9 @@
 fn main() {
     println!("cargo:rerun-if-changed=crt0.s");
     println!("cargo:rerun-if-changed=gba_mb.ld");
-    println!("cargo:rerun-if-changed=interrupt_simple.s");
     println!("cargo:rerun-if-changed=src/sound/mixer/mixer.s");
+    println!("cargo:rerun-if-changed=src/asm_include.s");
+    println!("cargo:rerun-if-changed=interrupt_handler.s");
     println!("cargo:rerun-if-changed=gfx/test_logo.png");
 
     let out_file_name = "crt0.o";
@@ -18,9 +19,11 @@ fn main() {
         .output()
         .expect("failed to compile crt0.s");
 
-    if !out.status.success() {
-        panic!("{}", String::from_utf8_lossy(&out.stderr));
-    }
+    assert!(
+        out.status.success(),
+        "{}",
+        String::from_utf8_lossy(&out.stderr)
+    );
 
     println!("cargo:rustc-link-search={}", out_dir);
 }
